@@ -3,15 +3,6 @@
 #'
 #' @description This function allows to convert a csv file to parquet format. \cr
 #'
-#' Several conversion possibilities are offered :
-#'
-#'\itemize{
-#'
-#' \item{From a locally stored file. Argument `path_to_csv` must then be used;}
-#' \item{From a URL. Argument `url_to_csv` must then be used.}
-#'
-#' }
-#'
 #' Two conversions possibilities are offered :
 #'
 #'\itemize{
@@ -21,10 +12,10 @@
 #'
 #' }
 #'
-#' @param path_to_csv string that indicates the path to the csv file
-#' @param url_to_csv string that indicates the URL of the csv file
-#' @param csv_as_a_zip boolean that indicates if the csv is stored in a zip
-#' @param filename_in_zip name of the csv file in the zip (useful if several csv are included in the zip). Required if `csv_as_a_zip` is TRUE.
+#' @param path_to_csv string that indicates the path or url to the csv file
+#' @param url_to_csv DEPRECATED use path_to_csv instead
+#' @param csv_as_a_zip DEPRECATED
+#' @param filename_in_zip name of the csv file in the zip. Required if several csv are included in the zip.
 #' @param path_to_parquet string that indicates the path to the directory where the parquet file will be stored
 #' @param columns character vector of columns to select from the input file (by default, all columns are selected).
 #' @param compression compression algorithm. Default "snappy".
@@ -48,7 +39,9 @@
 #' @importFrom curl curl_download
 #' @importFrom arrow write_parquet
 #' @importFrom utils unzip
-#' @importFrom cli cli_alert_danger cli_progress_message cli_alert_success
+#' @importFrom cli cli_alert_danger cli_progress_message cli_alert_success cli_alert_info
+#' @importFrom tidyselect all_of everything
+#' @importFrom lifecycle deprecate_warn deprecated
 #' @export
 #'
 #' @examples
@@ -82,7 +75,7 @@
 #' # Conversion from a URL and a csv file with "gzip" compression :
 #'
 #' csv_to_parquet(
-#'   url_to_csv =
+#'   path_to_csv =
 #'   "https://github.com/sidsriv/Introduction-to-Data-Science-in-python/raw/master/census.csv",
 #'   path_to_parquet = tempdir(),
 #'   compression = "gzip",
@@ -92,16 +85,15 @@
 #' # Conversion from a URL and a zipped file :
 #'
 #' csv_to_parquet(
-#'   url_to_csv = "https://www.nomisweb.co.uk/output/census/2021/census2021-ts007.zip",
-#'   csv_as_a_zip = TRUE,
+#'   path_to_csv = "https://www.nomisweb.co.uk/output/census/2021/census2021-ts007.zip",
 #'   filename_in_zip = "census2021-ts007-ctry.csv",
 #'   path_to_parquet = tempdir()
 #' )
 
 csv_to_parquet <- function(
     path_to_csv,
-    url_to_csv,
-    csv_as_a_zip = FALSE,
+    url_to_csv = deprecated(),
+    csv_as_a_zip = deprecated(),
     filename_in_zip,
     path_to_parquet,
     columns = "all",
@@ -110,136 +102,69 @@ csv_to_parquet <- function(
     partition = "no",
     encoding = "UTF-8",
     ...
-    ) {
+) {
+  if (!missing(url_to_csv)) {
+    lifecycle::deprecate_warn(
+      when = "0.5.5",
+      what = "csv_to_parquet(url_to_csv)",
+      details = "This argument is replaced by path_to_csv."
+    )
+  }
 
+  if (!missing(csv_as_a_zip)) {
+    lifecycle::deprecate_warn(
+      when = "0.5.5",
+      what = "csv_to_parquet(csv_as_a_zip)",
+      details = "This argument is no longer needed, parquetize detect zip file by extension."
+    )
+  }
 
   # Check if at least one of the two arguments path_to_csv or url_to_csv is set
   if (missing(path_to_csv) & missing(url_to_csv)) {
     cli_alert_danger("Be careful, you have to fill in either the path_to_csv or url_to_csv argument")
-  }
-
-  # Check if filename_in_zip is filled in when csv_as_a_zip is TRUE
-  if (csv_as_a_zip==TRUE & missing(filename_in_zip)) {
-    cli_alert_danger("Be careful, if the csv file is included in a zip then you must indicate the name of the csv file to convert")
+    stop("")
   }
 
   # Check if path_to_parquet is missing
   if (missing(path_to_parquet)) {
     cli_alert_danger("Be careful, the argument path_to_parquet must be filled in")
+    stop("")
   }
 
-  # Check if path_to_parquet exists
-  if (dir.exists(path_to_parquet)==FALSE) {
-    dir.create(path_to_parquet, recursive = TRUE)
-  }
+  dir.create(path_to_parquet, recursive = TRUE, showWarnings = FALSE)
 
   # Check if columns argument is a character vector
   if (isFALSE(is.vector(columns) & is.character(columns))) {
     cli_alert_danger("Be careful, the argument columns must be a character vector")
+    cli_alert_info('You can use `all` or `c("col1", "col2"))`')
+    stop("")
   }
 
+  if (missing(path_to_csv)) {
+    path_to_csv <- url_to_csv
+  }
+
+  input_file <- download_extract(path_to_csv, filename_in_zip)
+
   Sys.sleep(0.01)
   cli_progress_message("Reading data...")
 
-  if (missing(path_to_csv)==FALSE) {
+  csv_output <- read_delim(
+    file = input_file,
+    locale = locale(encoding = encoding),
+    lazy = TRUE,
+    show_col_types = FALSE,
+    col_select = if (identical(columns,"all")) everything() else all_of(columns)
+  )
 
-    # If we want to keep all columns
-    if (identical(columns,"all")) {
 
-      csv_output <- read_delim(file = path_to_csv,
-                               locale = locale(encoding = encoding),
-                               lazy = TRUE,
-                               show_col_types = FALSE)
+  Sys.sleep(0.01)
+  cli_progress_message("Writing data...")
 
-      # If you select the columns to be kept
-    } else {
-
-      csv_output <- read_delim(file = path_to_csv,
-                               locale = locale(encoding = encoding),
-                               lazy = TRUE,
-                               show_col_types = FALSE,
-                               col_select = columns)
-
-    }
-
-    Sys.sleep(0.01)
-    cli_progress_message("Writing data...")
-
-    parquetname <- paste0(gsub("\\..*","",sub(".*/","", path_to_csv)),".parquet")
-
-  } else if (missing(url_to_csv)==FALSE) {
-
-    if (csv_as_a_zip==FALSE) {
-
-      # If we want to keep all columns
-      if (identical(columns,"all")) {
-
-        csv_output <- read_delim(file = url_to_csv,
-                                 locale = locale(encoding = encoding),
-                                 lazy = TRUE,
-                                 show_col_types = FALSE)
-
-        # If you select the columns to be kept
-      } else {
-
-        csv_output <- read_delim(file = url_to_csv,
-                                 locale = locale(encoding = encoding),
-                                 lazy = TRUE,
-                                 show_col_types = FALSE,
-                                 col_select = columns)
-
-      }
-
-      parquetname <- paste0(gsub("\\..*","",sub(".*/","", url_to_csv)),".parquet")
-
-    } else if (csv_as_a_zip==TRUE) {
-
-      zip_file <- curl_download(url_to_csv,tempfile())
-      csv_file <- unzip(zipfile=zip_file,exdir=tempfile())
-      names(csv_file) <- sub('.*/', '', csv_file)
-
-      # If we want to keep all columns
-      if (identical(columns,"all")) {
-
-        csv_output <- read_delim(file = csv_file[[filename_in_zip]],
-                                 locale = locale(encoding = encoding),
-                                 lazy = TRUE,
-                                 show_col_types = FALSE)
-
-        # If you select the columns to be kept
-      } else {
-
-        csv_output <- read_delim(file = csv_file[[filename_in_zip]],
-                                 locale = locale(encoding = encoding),
-                                 lazy = TRUE,
-                                 show_col_types = FALSE,
-                                 col_select = columns)
-
-      }
-
-      parquetname <- paste0(gsub("\\..*","",filename_in_zip),".parquet")
-    }
-
-  }
-
-  if (partition %in% c("no")) {
-
-    parquetfile <- write_parquet(csv_output,
-                                 sink = file.path(path_to_parquet,
-                                                  parquetname),
-                                 ...
-    )
-
-  } else if (partition %in% c("yes")) {
-
-    parquetfile <- write_dataset(csv_output,
-                                 path = path_to_parquet,
-                                 ...)
-
-  }
+  parquetname <- get_parquet_file_name(input_file)
+  parquetfile <- write_data_in_parquet(csv_output, path_to_parquet, parquetname, partition, ...)
 
   cli_alert_success("\nThe csv file is available in parquet format under {path_to_parquet}")
 
   return(invisible(parquetfile))
-
 }
