@@ -1,5 +1,5 @@
-if (file.exists('Data')==FALSE) {
-  dir.create("Data")
+if (file.exists('Data_test')==FALSE) {
+  dir.create("Data_test")
 }
 
 test_that("Checks arguments are correctly filled in", {
@@ -11,7 +11,7 @@ test_that("Checks arguments are correctly filled in", {
   )
   expect_snapshot(
     rds_to_parquet(
-      path_to_parquet = "Data"
+      path_to_parquet = "Data_test"
     ),
     error = TRUE
   )
@@ -21,7 +21,7 @@ test_that("Checks message is displayed with rds file", {
   expect_snapshot(
     rds_to_parquet(
       path_to_rds = system.file("extdata","iris.rds",package = "parquetize"),
-      path_to_parquet = "Data"
+      path_to_parquet = "Data_test"
     )
   )
 })
@@ -31,7 +31,7 @@ test_that("Checks message is displayed with by adding partition and partitioning
   expect_snapshot(
     rds_to_parquet(
       path_to_rds = system.file("extdata","iris.rds",package = "parquetize"),
-      path_to_parquet = "Data",
+      path_to_parquet = "Data_test",
       partition = "yes",
       partitioning =  c("Species")
     )
